# Python SailPoint SDK

[![Discourse Topics][discourse-shield]][discourse-url]
![Times Downloaded][downloads-shield] ![Issues][issues-shield]
![Latest Releases][release-shield] ![Contributor Shield][contributor-shield]
![License Shield][license-shield]

[discourse-shield]: https://img.shields.io/discourse/topics?label=Discuss%20This%20Tool&server=https%3A%2F%2Fdeveloper.sailpoint.com%2Fdiscuss
[discourse-url]: https://developer.sailpoint.com/discuss
[downloads-shield]: https://img.shields.io/pypi/dw/sailpoint
[issues-shield]: https://img.shields.io/github/issues/sailpoint-oss/python-sdk?label=Issues
[release-shield]: https://img.shields.io/github/v/release/sailpoint-oss/python-sdk?label=Current%20Release
[contributor-shield]: https://img.shields.io/github/contributors/sailpoint-oss/python-sdk?label=Contributors
[license-shield]: https://img.shields.io/badge/MIT-License-green

## About the project

The Python SDK allows you to use Python to interact with the SailPoint APIs and other resources to customize and extend your SailPoint platform.

## Documentation

To get started with the Python SDK and learn about its various functionalities, refer to the [documentation](https://developer.sailpoint.com/docs/tools/sdk/python) on <https://developer.sailpoint.com>.

## Contributing

The SailPoint Developer Relations Team is always actively working to improve the SailPoint Python SDK to make it as useful as possible to the SailPoint Developer Community.
This means adding and maintaining new resources and functionalities for the SDK.
The most valuable resource of all, however, is the community itself!
We greatly appreciate any input, feedback, and direct contributions you can provide to the Python SDK, big or small.

Refer to our [contribution guidelines](./CONTRIBUTING.md) to learn more about the different ways you can contribute to the SDK.

Before you contribute, you [must sign our CLA](https://cla-assistant.io/sailpoint-oss/developer.sailpoint.com).

## License

Distributed under the MIT License. Refer to [the license](./LICENSE) for more information.

## Code of Conduct

We pledge to act and interact in ways that contribute to an open, welcoming, diverse, inclusive, and healthy community. Read our [code of conduct](./CODE_OF_CONDUCT.md) to learn more.
